@@ -37,11 +37,11 @@ application_author = "toroettg"  #: The application's author.
 application_author_name = "Tobias Roettger"  #: The author's name.
 application_author_email = "toroettg@gmail.com"  #: The author's contact information.
 
-application_version = "0.0.2"  #: The current version of the application.
+application_version = "0.0.3"  #: The current version of the application.
 
 application_description = "A TV series browser and tracker application."  #: A short description of the application.
 
-application_url = "http://code.google.com/p/seriesmarker/"  #: The project-website of the application.
+application_url = "http://toroettg.github.io/SeriesMarker"  #: The project-website of the application.
 
 application_license = "GNU GPLv3"  #: The license, under which the application is distributed.
 
